@@ -163,47 +163,78 @@ class VisionClassifierTrainer:
     # Get the hypothesis and predictions
     all_target, all_preds = self.__evaluate()
 
-    # Get the labels as a list
-    labels = list(self.labels2ids.values())
+    print(self.ids2labels.keys())
+    print(self.ids2labels.values())
+    print(set(all_target))
+    print(set(all_preds))
 
-    # Compute f-score
-    precision, recall, fscore, support = f_score(all_target, all_preds)
-
-    table_f_score = []
-
-    # Add macro scores for each classes
-    for i in range(len(labels)):
-        table_f_score.append(
-          [
-              labels[i],
-              ("0" if precision[i] < 1 else str(round(precision[i] * 100,2))) + " %",
-              ("0" if recall[i]    < 1 else str(round(recall[i]    * 100,2))) + " %",
-              ("0" if fscore[i]    < 1 else str(round(fscore[i]    * 100,2))) + " %",
-              support[i],
-          ]
-        )
-
-    # Add global macro scores
-    table_f_score.append(
-      [
-          "Macro",
-          str(round((sum(precision) / len(precision)) * 100, 2)) + " %",
-          str(round((sum(recall)    / len(recall))    * 100, 2)) + " %",
-          str(round((sum(fscore)    / len(fscore))    * 100, 2)) + " %",
-          str(sum(support)),
-      ]
+    from sklearn import metrics
+    table = metrics.classification_report(
+      all_target,
+      all_preds,
+      target_names = self.ids2labels.keys(),
+      labels = self.ids2labels.values(),
     )
+    print(table)
 
-    # Print precision, recall, f-score and support for each classes
-    f_score_table = tabulate(table_f_score, tablefmt="psql", headers=["Label", "Precision", "Recall", "F-Score", "Support"])
-    print(f_score_table)
+    # # Get the labels as a list
+    # labels = list(self.labels2ids.values())
 
-    # Write logs
-    self.__openLogs()
-    self.logs_file.write(f_score_table + "\n")
-    self.logs_file.close()
+    # # Compute f-score
+    # precision, recall, fscore, support = f_score(all_target, all_preds)
 
-    print("Logs saved at: \033[93m" + self.logs_path + "\033[0m")
+    # table_f_score = []
+
+    # # Add macro scores for each classes
+    # for i in range(len(labels)):
+
+    #   print(precision[i])
+    #   print(recall[i])
+    #   print(fscore[i])
+
+    #   if precision[i] > 0:
+    #     str_precision = str(round(precision[i] * 100,2)) + " %"
+    #   else:
+    #     str_precision = "0 %"
+
+    #   if recall[i] > 0:
+    #     str_recall = str(round(recall[i] * 100,2)) + " %"
+    #   else:
+    #     str_recall = "0 %"
+
+    #   if fscore[i] > 0:
+    #     str_fscore = str(round(fscore[i] * 100,2)) + " %"
+    #   else:
+    #     str_fscore = "0 %"
+
+    #   # Add local scores
+    #   table_f_score.append([
+    #     labels[i],
+    #     str_precision,
+    #     str_recall,
+    #     str_fscore,
+    #     support[i],
+    #   ])
+ 
+    # # Add global macro scores
+    # table_f_score.append([
+    #   "Macro",
+    #   str(round((sum(precision) / len(precision)) * 100, 2)) + " %",
+    #   str(round((sum(recall)    / len(recall))    * 100, 2)) + " %",
+    #   str(round((sum(fscore)    / len(fscore))    * 100, 2)) + " %",
+    #   str(sum(support)),
+    # ])
+
+    # # Print precision, recall, f-score and support for each classes
+    # f_score_table = tabulate(table_f_score, tablefmt="psql", headers=["Label", "Precision", "Recall", "F-Score", "Support"])
+    # print(f_score_table)
+
+    # # Write logs
+    # self.__openLogs()
+    # self.logs_file.write(f_score_table + "\n")
+    # self.logs_file.close()
+
+    # print("Logs saved at: \033[93m" + self.logs_path + "\033[0m")
 
     return all_target, all_preds
 
